package com.steerinfo.dil.mapper;

import com.steerinfo.dil.model.QmsQueueResult;
import com.steerinfo.framework.mapper.IBaseMapper;
import java.math.*;
import java.util.List;
import java.util.Map;

import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.apache.ibatis.annotations.Select;

@Mapper
public interface QmsQueueResultMapper extends IBaseMapper<QmsQueueResult, BigDecimal> {
    //查询最大主键
    @Select("select seq_qms_queue_result.nextval from dual")
    BigDecimal selectMaxId();

    //车辆进入电子围栏后触发排队申请 发送数据：运输订单号 返回 运力Id、实绩总表Id、订单ID
    Map<String, Object> queryCIdAndTIdByOrderNumber(@Param("orderNumber") String orderNumber);

    //通过运输订单Id查询推送给司机进厂的数据
//    Map<String, Object> sendEnFactoryMesToWebSocket(Integer orderId);

    //通过网格Id查询进厂门岗名称
//    Map<String, Object> queryGatepostNameByGridId(Integer gridId);

    //人工添加排队申请查询所有执行中订单 订单状态 ：1
//    List<Map<String, Object>> getAllExecutionOrder(Map<String, Object> map);

    //根据运输订单Id查询物资Id
    BigDecimal queryOrderMesByOrderId(BigDecimal orderId);

    //通过门岗名称查询门岗ID
//    BigDecimal getGatepostIdByGatepostName(String gatepostName);

    //通过月台名称查询月台ID
//    BigDecimal getPlatformIdByPlatformName(String platformName);

    //通过运输订单Id查询司机仓库排队的数据
//    Map<String, Object> sendWarehouseMesToWebSocket(Integer orderId);

    //通过月台网格ID查询仓库名称 和 月台名称
//    Map<String, Object> queryWarehouseNameByPlatformId(Integer gridId);

    //查询排队申请 判断条件：接收时间为空
    //查询指令下发 判断条件：接收时间为空
    List<Map<String, Object>> getQueueApply(Map<String, Object> map);

    //指令接收 通过接收时间判断是否已接收  查询判断条件：是否结束进厂
//    List<Map<String, Object>> getOrderReceive(Map<String, Object> map);

    //查询排队开始、详情数据  正在排队的数据
    List<Map<String, Object>> getQueueListByQueueUp(Map<String, Object> map);

    //查询排队详情
//    List<Map<String, Object>> getQueueMes(Map<String, Object> map);

    //查询排队转移详情
//    List<Map<String, Object>> getChangeQueueMes(Map<String, Object> map);

    //通过实绩Id查询链表ID
    Map<String, Object> getListIdByResultId(BigDecimal resultId);

    //查询排队取消
    List<Map<String, Object>> getQueueCancel(Map<String, Object> map);

    //修改排队取消
    Integer updateCancelResult(QmsQueueResult qmsQueueResult);

    //通过实绩Id查询排队取消实绩
    List<Map<String, Object>> getQueueCancelByResultId(Integer resultId);

    //查询插队详情
//    List<Map<String, Object>> getQueueInsert(Map<String, Object> map);

    //查询排队结束
    List<Map<String, Object>> getQueueEndResult(Map<String, Object> map);

    //汽车监控
    List<Map<String, Object>> capacityMonitor(Map<String, Object> map);



    /*============================================仓库排队====================================*/
    //查询仓库排队申请 系统自动下发 查询指令下发
//    List<Map<String, Object>> getWarehouseQueueApply(Map<String, Object> map);

    //查询仓库指令接收
//    List<Map<String, Object>> getWarehouseOrderReceive(Map<String, Object> map);

    //查询仓库排队开始
//    List<Map<String, Object>> getWarehouseQueueListByQueueUp(Map<String, Object> map);

//    查看仓库排队详情 通过运输订单号
//    List<Map<String, Object>> getWarehouseQueueMes(Map<String, Object> map);

    //查询仓库排队转移
//    List<Map<String, Object>> getWarehouseQueueChange(Map<String, Object> map);

    //查询仓库排队结束
//    List<Map<String, Object>> getWarehouseQueueEndMes(Map<String, Object> map);

    /*
    ***************APP**********************
    */

    // 通过门岗查询门岗的排队数
//    List<Map<String, Object>> getQueueListByGatepost(BigDecimal gatepostId);

    // 查询排队取消列表
//    List<Map<String, Object>> getQueueCancelList();

    // 查看各个门岗,仓库的实时状态
//    List<Map<String, Object>> getQueueStatusList();

    // 查询司机接单列表
//    List<Map<String, Object>> getOrderReceiveList();

    // 查询司机接单
    List<Map<String, Object>> getOrderReceive2(Map<String,Object> map);

    // 通过运单号得到总实绩id
    BigDecimal getResultTotalId(String orderNumber);

    // 通过总实绩id和运单id查询排队实绩id
    BigDecimal getQueueResultId(Map<String,Object> map);

    // 通过运力id得到实绩id
    BigDecimal getResultIdByCapacityId(String capacityNumber);

    // 通过车牌号得到网格id
//    BigDecimal getGridId(String capacityNumber);

    // 通过车牌号得到网格id
//    BigDecimal getGridIdNotNull(String capacityNumber);

   /*
   ==================================================2022年4月8日19:39:18========================================
    */
    //查询网格Id
    BigDecimal getGridIdByOrderId(BigDecimal orderId);

    //查询物资ID
    Integer getMaterialIdByOrderId(BigDecimal orderId);

    Map<String, Object> getQueueResultByOrderId(BigDecimal resultTotalId);

    Map<String, Object> getResultMesByTotalId(BigDecimal resultTotalId);

    List<Map<String, Object>> getQueueListByQueueUpSpelling(Map<String, Object> map);

    List<Map<String,Object>> getMaterialId(BigDecimal orderId);

    List<Map<String,Object>> getStoreQueueList();

    /**
     * @author:zyf
     * @version:1.0
     * @Date:2022-09-27
     * @Description:查询已派车数量（钢材）
     */
    int querySentCarNumber();

    /**
     * @author:zyf
     * @version:1.0
     * @Date:2022-09-27
     * @Description:查询已进厂数量（钢材）
     */
    int queryIntoFactoryNumber();

    /**
     * @author:zyf
     * @version:1.0
     * @Date:2022-09-27
     * @Description:查询已出厂数量（钢材）
     */
    int queryLeaveFactoryNumber();

    /**
     * @author:zyf
     * @version:1.0
     * @Date:2022-10-27
     * @Description:复刻出厂数
    */
    List<Map<String, Object>>   getCapacityByDefend(Map<String, Object> map);

    /**
     * @author:zyf
     * @version:1.0
     * @Date:2022-10-28
     * @Description:复刻进厂数
    */
    int getSteelOrderNum();
}