package com.steerinfo.dil.service.impl;

import com.steerinfo.dil.mapper.QmsQueueListMapper;
import com.steerinfo.dil.mapper.QmsQueueSpellingListMapper;
import com.steerinfo.dil.mapper.QueuingRulesMapper;
import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 定时器单拼多拼多线程使用
 */

@Component
public class QueueDealWithAsync {

    @Resource
    private QueuingRulesMapper queuingRulesMapper;

    @Autowired
    private QmsQueueListMapper qmsQueueListMapper;

    @Lazy
    @Autowired
    private QmsQueueSpellingListMapper qmsQueueSpellingListMapper;

    /**
     * 单拼
     * @param nowTime
     */
    @Async("taskExecutor")
    public void dealWithOne(long nowTime){
        //查询所有单拼排队网格已经确认进厂的记录
        List<Map<String, Object>> listListMap = queuingRulesMapper.getAllSureTimeList();
        for (Map<String, Object> map : listListMap) {
            if((nowTime - ((Date) map.get("entrySureTime")).getTime()) > 10800000){
                //如果超过勾选时间30分钟 自动回滚到队列最后--修改为1个小时
                BigDecimal listId = DataChange.dataToBigDecimal(map.get("listId"));
                Integer maxListNodeOrder = qmsQueueListMapper.getMaxListNodeOrder(map);
                queuingRulesMapper.updateListToLast(listId, maxListNodeOrder + 1);
                //移除可进厂资格
                queuingRulesMapper.updateEnFactory(DataChange.dataToBigDecimal(map.get("resultTotalId")));
                if((nowTime - ((Date) map.get("insertTime")).getTime()) > 86400000){
                    //如果大于一天则直接删除队列信息
                    qmsQueueListMapper.deleteByPrimaryKey(listId);
                    queuingRulesMapper.updateQQRRemoveList(DataChange.dataToBigDecimal(map.get("resultId")));
                }
            }
        }
    }


    /**
     * 单拼
     * @param nowTime
     */
    @Async("taskExecutor")
    public void dealWithTwo(long nowTime){
        //查询所有多拼排队网格已经确认进厂的记录
        List<Map<String, Object>> allSureTimeSpellingList = queuingRulesMapper.getAllSureTimeSpellingList();
        for (Map<String, Object> map : allSureTimeSpellingList) {
            if ((nowTime - ((Date) map.get("entrySureTime")).getTime()) > 10800000) {
                BigDecimal spellingResultId = DataChange.dataToBigDecimal(map.get("spellingResultId"));
                //如果超过勾选时间30分钟 自动回滚到队列最后
                queuingRulesMapper.updateSpellingListToLast(spellingResultId);
                //移除可进厂资格
                queuingRulesMapper.updateEnFactory(DataChange.dataToBigDecimal(map.get("resultTotalId")));
                if((nowTime - ((Date) map.get("spellingSureTime")).getTime()) > 86400000){
                    //如果大于一天则直接删除队列信息
                    qmsQueueSpellingListMapper.deleteByPrimaryKey(spellingResultId);
                    queuingRulesMapper.updateQQRRemoveList(DataChange.dataToBigDecimal(map.get("resultId")));
                }
            }
        }
    }

    /**
     * 多拼
     * @param nowTime
     */
    @Async("taskExecutor")
    public void dealWithThree(long nowTime){
        List<Map<String, Object>> listMap = queuingRulesMapper.getAllNotSureEnFactoryList();
        for (Map<String, Object> map : listMap) {
            if((nowTime - ((Date) map.get("insertTime")).getTime()) > 86400000){
                //踢出队列
                qmsQueueListMapper.deleteByPrimaryKey(DataChange.dataToBigDecimal(map.get("listId")));
                //修改信息
                queuingRulesMapper.updateQQRRemoveList(DataChange.dataToBigDecimal(map.get("resultId")));
            }
        }
    }


    /**
     * 多拼
     * @param nowTime
     */
    @Async("taskExecutor")
    public void dealWithFour(long nowTime){
        List<Map<String, Object>> spellingListMap = queuingRulesMapper.getAllNotSureEnFactorySpellingList();
        for (Map<String, Object> map : spellingListMap) {
            if((nowTime - ((Date) map.get("spellingSureTime")).getTime()) > 86400000){
                //如果大于一天则直接删除队列信息
                qmsQueueSpellingListMapper.deleteByPrimaryKey(DataChange.dataToBigDecimal(map.get("spellingResultId")));
                queuingRulesMapper.updateQQRRemoveList(DataChange.dataToBigDecimal(map.get("resultId")));
            }
        }
    }

}
